@@ -1,6 +1,6 @@
 import time
 
-from birdbrain_hummingbird import BirdbrainHummingbird
+from birdbrain_python_library_2.birdbrain_hummingbird import BirdbrainHummingbird
 
 myBird = Hummingbird('A')
 
